@@ -124,7 +124,7 @@ class Text_Dataset:
             pos = random.randint(0, len(text) - length)
             sample = text[pos:pos+length]
         if sanitize_white_space is True:
-            sample = self.filter_text(sample, sanitize_white_space, separate_punctuation, preserve_case)
+            sample = self.filter_text(sample, sanitize_white_space=sanitize_white_space, separate_punctuation=separate_punctuation, preserve_case=preserve_case)
         return (idx, sample)
 
     def _word_splitter(self, text):
@@ -238,9 +238,10 @@ class Text_Dataset:
         :param length: length of the sample
         :return: tuple (X, y) encoded sample
         """
-        _, sample = self.encode(self.get_random_sample(length+1, sanitize_white_space=False), tokenizer='char')
-        X = sample[:-1]
-        y = sample[1:]
+        _, sample = self.get_random_sample(length+1, sanitize_white_space=False)
+        e_sample = self.encode(sample, tokenizer='char')
+        X = e_sample[:-1]
+        y = e_sample[1:]
         return X, y
         
     def _display_colored_html(self, textlist, dark_mode=False, display_ref_anchor=True, pre='', post=''):
